@@ -168,11 +168,16 @@ fn generate_api_func(func: &ApiFunc) -> (String, String, String) {
         func.inputs
             .iter()
             .map(|input| {
-                format!(
-                    "_api2wire_{}({})",
-                    &input.ty.safe_ident(),
-                    &input.name.dart_style()
-                )
+                // edge case: ffigen performs its own bool-to-int conversions
+                if let ApiType::Primitive(ApiTypePrimitive::Bool) = input.ty {
+                    input.name.dart_style()
+                } else {
+                    format!(
+                        "_api2wire_{}({})",
+                        &input.ty.safe_ident(),
+                        &input.name.dart_style()
+                    )
+                }
             })
             .collect::<Vec<_>>(),
     ]
@@ -249,6 +254,7 @@ fn generate_api_func(func: &ApiFunc) -> (String, String, String) {
 
 fn generate_api2wire_func(ty: &ApiType) -> String {
     let body = match ty {
+        Primitive(ApiTypePrimitive::Bool) => "return raw ? 1 : 0;".to_owned(),
         Primitive(_) => "return raw;".to_string(),
         Delegate(d) => match d {
             ApiTypeDelegate::String => {
@@ -360,18 +366,6 @@ fn generate_api_fill_to_wire_func(ty: &ApiType, api_file: &ApiFile) -> String {
                 } else {
                     let r = format!("wireObj.kind.ref.{}.ref", variant.name);
                     let body: Vec<_> = match &variant.kind {
-                        ApiVariantKind::Tuple(types) => types
-                            .iter()
-                            .enumerate()
-                            .map(|(idx, ty)| {
-                                format!(
-                                    "{}.field{1} = _api2wire_{2}(apiObj.field{1});",
-                                    r,
-                                    idx,
-                                    ty.safe_ident()
-                                )
-                            })
-                            .collect(),
                         ApiVariantKind::Struct(st) => st
                             .fields
                             .iter()
@@ -491,32 +485,27 @@ fn generate_wire2api_func(ty: &ApiType, api_file: &ApiFile) -> String {
                 .enumerate()
                 .map(|(idx, variant)| {
                     let args = match &variant.kind {
-                        ApiVariantKind::Value => "()".to_owned(),
-                        ApiVariantKind::Tuple(types) => {
-                            let args = (1..=types.len())
-                                .map(|idx| format!("raw[{}]", idx))
-                                .collect::<Vec<_>>();
-                            format!("({})", args.join(","))
-                        }
-                        ApiVariantKind::Struct(s) => {
-                            let args = s
-                                .fields
-                                .iter()
-                                .enumerate()
-                                .map(|(idx, field)| {
-                                    format!("{}: raw[{}]", field.name.dart_style(), idx + 1)
-                                })
-                                .collect::<Vec<_>>();
-                            format!("({})", args.join(","))
-                        }
+                        ApiVariantKind::Value => "".to_owned(),
+                        ApiVariantKind::Struct(st) => st
+                            .fields
+                            .iter()
+                            .enumerate()
+                            .map(|(idx, field)| {
+                                let val = format!(
+                                    "_wire2api_{}(raw[{}]),",
+                                    field.ty.safe_ident(),
+                                    idx + 1
+                                );
+                                if st.is_fields_named {
+                                    format!("{}: {}", field.name.dart_style(), val)
+                                } else {
+                                    val
+                                }
+                            })
+                            .collect::<Vec<_>>()
+                            .join(""),
                     };
-                    format!(
-                        "case {}: return {}.{}{};",
-                        idx,
-                        enu.name,
-                        variant.name.dart_style(),
-                        args
-                    )
+                    format!("case {}: return {}({});", idx, variant.name, args)
                 })
                 .collect::<Vec<_>>();
             format!(
@@ -601,18 +590,28 @@ fn generate_api_enum(enu: &ApiEnum) -> String {
             .map(|variant| {
                 let args = match &variant.kind {
                     ApiVariantKind::Value => "".to_owned(),
-                    ApiVariantKind::Tuple(types) => {
-                        let split = optional_boundary_index(types);
-                        let types = types
+                    ApiVariantKind::Struct(ApiStruct {
+                        is_fields_named: false,
+                        fields,
+                        ..
+                    }) => {
+                        let types = fields.iter().map(|field| &field.ty).collect::<Vec<_>>();
+                        let split = optional_boundary_index(&types);
+                        let types = fields
                             .iter()
-                            .enumerate()
-                            .map(|(idx, typ)| format!("{} field{}", typ.dart_api_type(), idx))
+                            .map(|field| {
+                                format!(
+                                    "{}{} {},",
+                                    dart_comments(&field.comments),
+                                    field.ty.dart_api_type(),
+                                    field.name.dart_style()
+                                )
+                            })
                             .collect::<Vec<_>>();
                         if let Some(idx) = split {
                             let before = &types[..idx];
                             let after = &types[idx..];
-                            let sep = if before.is_empty() { "" } else { "," };
-                            format!("{}{} [{}]", before.join(","), sep, after.join(","))
+                            format!("{}[{}]", before.join(""), after.join(""))
                         } else {
                             types.join(",")
                         }
@@ -623,18 +622,20 @@ fn generate_api_enum(enu: &ApiEnum) -> String {
                             .iter()
                             .map(|field| {
                                 format!(
-                                    "{}{} {}",
+                                    "{}{}{} {},",
+                                    dart_comments(&field.comments),
                                     field.ty.required_modifier(),
                                     field.ty.dart_api_type(),
                                     field.name.dart_style()
                                 )
                             })
                             .collect::<Vec<_>>();
-                        format!("{{ {} }}", fields.join(","))
+                        format!("{{ {} }}", fields.join(""))
                     }
                 };
                 format!(
-                    "const factory {}.{}({}) = {};",
+                    "{}const factory {}.{}({}) = {};",
+                    dart_comments(&variant.comments),
                     enu.name,
                     variant.name.dart_style(),
                     args,
